@@ -8,13 +8,13 @@ import (
 type nodePhase string
 
 // Workflow and node statuses
+// See: https://github.com/argoproj/argo-workflows/blob/master/pkg/apis/workflow/v1alpha1/workflow_phase.go
 const (
 	nodePending   nodePhase = "Pending"
 	nodeRunning   nodePhase = "Running"
 	nodeSucceeded nodePhase = "Succeeded"
-	// nodeSkipped   nodePhase = "Skipped"
-	nodeFailed nodePhase = "Failed"
-	nodeError  nodePhase = "Error"
+	nodeFailed    nodePhase = "Failed"
+	nodeError     nodePhase = "Error"
 )
 
 // An agnostic workflow object only considers Status.Phase and Status.Message. It is agnostic to the API version or any
@@ -33,12 +33,12 @@ func getArgoWorkflowHealth(obj *unstructured.Unstructured) (*HealthStatus, error
 		return nil, err
 	}
 	switch wf.Status.Phase {
-	case nodePending, nodeRunning:
+	case "", nodePending, nodeRunning:
 		return &HealthStatus{Status: HealthStatusProgressing, Message: wf.Status.Message}, nil
 	case nodeSucceeded:
 		return &HealthStatus{Status: HealthStatusHealthy, Message: wf.Status.Message}, nil
 	case nodeFailed, nodeError:
 		return &HealthStatus{Status: HealthStatusDegraded, Message: wf.Status.Message}, nil
 	}
-	return &HealthStatus{Status: HealthStatusHealthy, Message: wf.Status.Message}, nil
+	return &HealthStatus{Status: HealthStatusUnknown, Message: wf.Status.Message}, nil
 }
